import axios from 'axios'
import { message } from 'antd'

const prefix = '/api/v1'

export const request = axios.create({
  baseURL: `${prefix}`,
  timeout: 50000
})

request.interceptors.request.use(config => {
  if (localStorage.getItem('area-token')) {
    config.headers['token'] = localStorage.getItem('area-token')
  }
  return config
})

const errorHandler = code => {
  switch (code) {
    case 10009:
        window.location.href = '/login'
      break
  }
}

request.interceptors.response.use(response => {
  if (response.data.code) {
    const error = response.data.message
    message.error(error)
    errorHandler(response.data.code)
    throw error
  }
  return response.data
})

export default request
