import React, { FC } from 'react'
import {
  Form,
  Input,
  Button,
  Row,
  Col,
  Upload,
  Select,
  InputNumber,
  message
} from 'antd'
import { UploadOutlined } from '@ant-design/icons'
import { CreateCompany } from '../../services/api'
import './index.scss'

const proveForm = [
  {
    label: '法人代表',
    name: 'legal_person'
  },
  {
    label: '详细地址',
    name: 'company_addr'
  },
  {
    label: '统一社会信用代码',
    name: 'social_code'
  }
]
const accountForm = [
  {
    label: '用户名',
    name: 'username'
  },
  {
    label: '密码',
    name: 'password'
  }
]
const basicInfoForm = [
  {
    label: '申请人',
    name: 'applicant'
  },
  {
    label: '申请人联系电话',
    name: 'applicant_phone'
  },
  {
    label: '企业名称',
    name: 'company_name'
  },
  {
    label: '企业联系电话',
    name: 'company_phone'
  },
  {
    label: '申请人职务',
    name: 'applicant_duty'
  },
]

const AddCompany: FC = () => {
  const uploadProps: any = {
    name: "file",
    action: "/api/v1/upload",
    headers: {
      token: localStorage.getItem('area-token')
    },
    listType: "picture",
    maxCount: 1
  }
  const [form]: any = Form.useForm()
  const handleCreateCompany = () => {
    form.validateFields()
      .then(async values => {
        await CreateCompany({
          ...values,
          business_license: 'https://hbimg.huabanimg.com/e6ad1c576bd8eb94dd6c455b0eaf6c7a34769c8c1b4718-AI95K9_fw658/format/webp',
          applicant_identification: 'https://hbimg.huabanimg.com/e6ad1c576bd8eb94dd6c455b0eaf6c7a34769c8c1b4718-AI95K9_fw658/format/webp'
        })
        message.success('添加成功')
      })
    return
  }

  return (
    <div className="custom-form-box">
      <Form
        form={form}
        name='form'
        labelCol={{ span: 5 }}
        wrapperCol={{ span: 9 }}
        initialValues={{ remember: true }}
        labelAlign={'right'}
      >
        <Row>
          <Col span={12}>
            <div className='form-group-title'>基本信息</div>
            {
              basicInfoForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  required
                  key={item.name}
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  <Input placeholder='单行输入' />
                </Form.Item>
              ))
            }
            <Form.Item label='身份证明' wrapperCol={{ span: 2 }} name='applicant_identification'>
              <Upload {...uploadProps}>
                <Button style={{ width: '100%' }} icon={<UploadOutlined />}>选择文件</Button>
              </Upload>
            </Form.Item>
          </Col>
          <Col span={12}>
            <div className='form-group-title'>账户信息</div>
            {
              accountForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                  required
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  <Input placeholder='单行输入' />
                </Form.Item>
              ))
            }
          </Col>
        </Row>
        <Row className='form-group'>
          <Col span={12}>
            <div className='form-group-title'>资质信息</div>
            {
              proveForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                  required
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  <Input placeholder='单行输入' />
                </Form.Item>
              ))
            }
            <Form.Item
              label='证件类型'
              wrapperCol={{ span: 2 }}
              valuePropName='option'
              name='license_type'
            >
              <Select style={{ width: 180 }} placeholder='多证合一营业执照'>
                <Select.Option value={0}>Type 0</Select.Option>
                <Select.Option value='1'>Type 1</Select.Option>
                <Select.Option value='2'>Type 2</Select.Option>
                <Select.Option value='3'>Type 3</Select.Option>
              </Select>
            </Form.Item>
            <Form.Item label='营业执照' wrapperCol={{ span: 2 }}>
              <Upload name="business_license" action="/upload.do" listType="picture">
                <Button style={{ width: '100%' }} icon={<UploadOutlined />}>选择文件</Button>
              </Upload>
            </Form.Item>
          </Col>
        </Row>
        <Row className='form-group'>
          <Col span={12}>
            <div className='form-group-title'>权限信息</div>
            <Form.Item
              label="免费小区个数"
              name="free_garden_count"
              required
              rules={[{ required: true, message: '请输入小区个数!' }]}
              wrapperCol={{ span: 3 }}
            >
              <InputNumber style={{ width: '140px' }} placeholder='请选择' />
            </Form.Item>
          </Col>
        </Row>
        <Form.Item wrapperCol={{ span: 24 }}>
          <Button type="primary" size='large' onClick={() => {
            handleCreateCompany()
          }}>
            添加
          </Button>
        </Form.Item>
      </Form>
    </div>
  )
}

export default AddCompany
