import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, InputNumber, Row, Image } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { BasicInfoForm, ProveForm } from './map'
import { GetCompanyList } from '../../services/api'

const CompanyList: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id'
    },
    {
      title: '申请人',
      dataIndex: 'applicant'
    },
    {
      title: '申请人联系电话',
      dataIndex: 'applicant_phone'
    },
    {
      title: '公司名称',
      dataIndex: 'company_name'
    },
    {
      title: '公司电话',
      dataIndex: 'company_phone',
      search: false,
    },
    {
      title: '申请人职务',
      dataIndex: 'applicant_duty',
      search: false,
    },
    {
      title: '身份证明',
      dataIndex: 'applicant_identification',
      search: false,
      render: (_, row, index, action) => [
        <Image
          width={200}
          src={row.applicant_identification}
        />
      ]
    },
    {
      title: '申请时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '审核状态',
      dataIndex: 'approve_status',
      valueEnum: {
        0: {
          text: '所有',
          status: 'Default',
        },
        1: {
          text: '待审核',
          status: 'Processing',
        },
        2: {
          text: '未通过',
          status: 'Danger',
        },
        3: {
          text: '已通过',
          status: 'Success',
        }
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      render: (_, row, index, action) => [
        <Button type='link' onClick={() => {
          setRowData(row)
          setState(pre => ({ ...pre, examineVisible: true }))
        }}>审核</Button>,
        <Button type='link' onClick={() => {
          setState(pre => ({ ...pre, visible: true }))
        }}>配额</Button>
      ]
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    examineVisible: false
  })
  const [rowData, setRowData] = useState({})
  const [form]: any = Form.useForm()

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <ProTable
        headerTitle="物业公司"
        actionRef={actionRef}
        rowKey="key"
        search={{ labelWidth: 120 }}
        request={GetCompanyList}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              props.history.push('/admin/company/add')
            }}
          >
            <PlusOutlined /> 新建
          </Button>
        ]}
        columns={columns}
      />
      <Modal
        visible={state.visible}
        title='配额'
        onOk={() => setState(pre => ({ ...pre, visible: false }))}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form>
          <Form.Item label='新增小区数'>
            <InputNumber placeholder='请输入'/>
            <div style={{ marginTop: 5 }}>当前个数：8       操作后个数：10</div>
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='审核'
        visible={state.examineVisible}
        onOk={() => setState(pre => ({ ...pre, examineVisible: false }))}
        onCancel={() => setState(pre => ({ ...pre, examineVisible: false }))}
      >
        <Form
          labelCol={{ span: 7 }}
          wrapperCol={{ span: 9 }}
          form={form}
        >
          <Row>
            <div className='examine-form-title'>基本信息</div>
            {
              BasicInfoForm.map(item => (
                <Form.Item
                  style={{ width: '100%' }}
                  label={item.label}
                  key={item.name}
                  required
                >
                  { rowData[item.name] }
                </Form.Item>
              ))
            }
          </Row>
          <Row>
            <div className='examine-form-title'>资质信息</div>
            {
              ProveForm.map(item => (
                <Form.Item
                  style={{ width: '100%' }}
                  label={item.label}
                  key={item.name}
                  required
                >
                  { rowData[item.name] }
                </Form.Item>
              ))
            }
          </Row>
          <Row>
            <div className='examine-form-title'>权限信息</div>
            <Form.Item label='免费小区个数' name='free_garden_count' style={{ width: '100%' }}>
              <InputNumber value={rowData['free_garden_count']} style={{ width: '140px' }} placeholder='请选择' />
            </Form.Item>
          </Row>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default CompanyList