import * as React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Card } from 'antd'
import { GetGardenList, GetProvinceCityArea } from '../../services/api'

const GardenList: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: '小区名称',
      dataIndex: 'name'
    },
    {
      title: '小区地址',
      dataIndex: 'name'
    },
    {
      title: '所属物业公司',
      dataIndex: 'id',
      valueEnum: {
        0: {
          text: '测试',
          status: 'Default',
        }
      }
    },
    {
      title: '物业联系人',
      dataIndex: 'name'
    },
    {
      title: '物业联系人手机号',
      dataIndex: 'company_phone',
      search: false,
    },
    {
      title: '社区',
      dataIndex: 'id'
    },
    {
      title: '街道',
      dataIndex: 'id'
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      render: (_, row, index, action) => [
        <Button type='link' onClick={() => {
          setState(pre => ({ ...pre, visible: true }))
        }}>修改所属物业公司</Button>
      ]
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    examineVisible: false
  })
  const [areaData, setAreaData] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })
  // cache
  const [areaDataCache, setAreaDataCache] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })

  React.useEffect(() => {
    GetProvinceCityArea({}).then(res => {
      setAreaDataCache(res.data)
      setAreaData(pre => ({
        ...pre,
        province_list: res.data.province_list
      }))
      console.log(areaDataCache.city_list)
    })
  }, [])

  const actionRef = React.useRef<ActionType>();
  return (
    <React.Fragment>
      <Card>
        <Select
          placeholder='省份'
          style={{ width: 200 }}
          onChange={
            (value) => {
              setAreaData(pre => ({
                ...pre,
                city_list: areaDataCache.city_list.filter((item: any) => item.province_code === value)
              }))
            }
          }>
          {
            areaData.province_list.map((province: any) => {
              return <Select.Option value={province.code} key={province.code}>{province.name}</Select.Option>
            })
          }
        </Select>
        <Select
          placeholder='城市'
          style={{ width: 200 }}
          onChange={
            (value) => {
              setAreaData(pre => ({
                ...pre,
                area_list: areaDataCache.area_list.filter((item: any) => item.city_code === value)
              }))
            }
          }
        >
          {
            areaData.city_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.code}>{item.name}</Select.Option>
            })
          }
        </Select>
        <Select placeholder='区域' style={{ width: 200 }}>
          {
            areaData.area_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.code}>{item.name}</Select.Option>
            })
          }
        </Select>
      </Card>
      <ProTable
        headerTitle="小区列表"
        actionRef={actionRef}
        rowKey="key"
        search={{ labelWidth: 120 }}
        request={() => {
          return Promise.resolve({
            total: 200,
            data: [{}],
            success: true,
          });
        }}
        toolBarRender={() => []}
        columns={columns}
      />
      <Modal
        visible={state.visible}
        title='修改小区所属物业公司'
        onOk={() => setState(pre => ({ ...pre, visible: false }))}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form>
          <Form.Item label='所属物业公司'>
            <Select placeholder='请选择'>
              <Select.Option value='1'>
                测试
              </Select.Option>
            </Select>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default GardenList